.. webapi-error::
   :instance: djblets.webapi.errors.LOGIN_FAILED

   Your client attempted to log in, but didn't provide valid credentials.
   You'll be provided with ``WWW-Authenticate`` HTTP headers so your client
   can try again.

   See :ref:`2.0-authenticating` for more information.
